==> foundation-2.6.1.tgz: package/PageCsv/PageCsv.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const PageCsv = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M40.416 64.173c.831 0 1.55.623 1.786 1.342l2.408-1.121c-.553-1.273-1.771-2.685-4.193-2.685-2.893 0-5.079 1.924-5.079 4.775 0 2.837 2.187 4.774 5.079 4.774 2.422 0 3.654-1.467 4.193-2.699l-2.408-1.107c-.235.719-.955 1.342-1.786 1.342-1.342 0-2.242-1.024-2.242-2.311s.9-2.31 2.242-2.31zm8.189.319c0-.235.152-.415.706-.415.872 0 1.91.304 2.712.913l1.495-1.979c-1.052-.858-2.408-1.287-3.917-1.287-2.533 0-3.833 1.495-3.833 3.059 0 3.64 5.148 2.74 5.148 3.626 0 .36-.498.499-1.024.499a4.304 4.304 0 01-2.976-1.19l-1.453 2.076c.982.886 2.325 1.467 4.291 1.467 2.477 0 3.986-1.176 3.986-3.211 0-3.434-5.135-2.686-5.135-3.558zm10.896 3.584l-1.993-6.214h-3.169l3.404 9.231h3.515l3.405-9.231h-3.169z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M80.277 12.5h-.005V8.48a1.73 1.73 0 00-1.73-1.73h-32.87L19.722 32.7v58.819c0 .956.774 1.73 1.73 1.73h57.09a1.73 1.73 0 001.73-1.73v-2.448h.005V12.5zM29.679 83.294V36.16h17.723a1.73 1.73 0 001.73-1.73V16.707H70.32v66.587H29.679z"
  }));
});
PageCsv.displayName = 'PageCsv';
export const PageCsvDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/PageCsv/PageCsv.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var PageCsv = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M40.416 64.173c.831 0 1.55.623 1.786 1.342l2.408-1.121c-.553-1.273-1.771-2.685-4.193-2.685-2.893 0-5.079 1.924-5.079 4.775 0 2.837 2.187 4.774 5.079 4.774 2.422 0 3.654-1.467 4.193-2.699l-2.408-1.107c-.235.719-.955 1.342-1.786 1.342-1.342 0-2.242-1.024-2.242-2.311s.9-2.31 2.242-2.31zm8.189.319c0-.235.152-.415.706-.415.872 0 1.91.304 2.712.913l1.495-1.979c-1.052-.858-2.408-1.287-3.917-1.287-2.533 0-3.833 1.495-3.833 3.059 0 3.64 5.148 2.74 5.148 3.626 0 .36-.498.499-1.024.499a4.304 4.304 0 01-2.976-1.19l-1.453 2.076c.982.886 2.325 1.467 4.291 1.467 2.477 0 3.986-1.176 3.986-3.211 0-3.434-5.135-2.686-5.135-3.558zm10.896 3.584l-1.993-6.214h-3.169l3.404 9.231h3.515l3.405-9.231h-3.169z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M80.277 12.5h-.005V8.48a1.73 1.73 0 00-1.73-1.73h-32.87L19.722 32.7v58.819c0 .956.774 1.73 1.73 1.73h57.09a1.73 1.73 0 001.73-1.73v-2.448h.005V12.5zM29.679 83.294V36.16h17.723a1.73 1.73 0 001.73-1.73V16.707H70.32v66.587H29.679z"
  }));
});
PageCsv.displayName = 'PageCsv';
export var PageCsvDimensions = {
  height: 100,
  width: 100
};
